```{include} ../../README.md

```

## Get in touch

- If you encounter any errors or problems with **pop-tools**, please open an issue at the GitHub [main repository](http://github.com/NCAR/pop-tools/issues).
- If you have a question like “How do I compute x?”, ask on [GitHub discussions](https://github.com/NCAR/pop-tools/discussions). Please include a self-contained reproducible example if possible.

```{toctree}
---
maxdepth: 2
caption: User Guide
hidden:
---
install
examples/index
```

```{toctree}
---
maxdepth: 2
caption: Reference
hidden:
---
api.rst
```

```{toctree}
---
maxdepth: 1
caption: Contribute to pop-tools
hidden:
---
contributing
changelog
GitHub Repo <https://github.com/NCAR/pop-tools>
GitHub discussions <https://github.com/NCAR/pop-tools/discussions>
```
